.. include:: ../README.rst

Contents
========

.. toctree::
   :maxdepth: 2

   install
   usage
   performances
   chessboard
   development
   changelog
   license


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
